/*
 *  Copyright (c) 2006-2008, Lars Engels <lars.engels@0x20.net>
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without modification,
 *  are permitted provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the documentation and/or
 *     other materials provided with the distribution.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 *  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 *  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 *  ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 *  (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#define FONT           "-adobe-helvetica-bold-r-normal-*-*-320-*-*-p-*-*-*"
#define COLOR          "green"
#define ALARM_COLOR    "red"
#define POS_X          10
#define POS_Y          48
#define XOSD_WIDTH     50
#define SLEEP          1500000
#define ALARM_PCT      7

#define GETSYSCTL(name, var)  sysctlbyname(name, &(var), sizeof(var), NULL, 0)
#define SYSCTL_CPU_FREQ         "dev.cpu.0.freq"
#define SYSCTL_CPU_FREQ_LEVELS  "dev.cpu.0.freq_levels"
#define SYSCTL_BATTERY_LIFE     "hw.acpi.battery.life"
#define SYSCTL_BATTERY_STATE    "hw.acpi.battery.state"
#define SYSCTL_BATTERY_STATE    "hw.acpi.battery.state"
#define SYSCTL_BATTERY_TIME     "hw.acpi.battery.time"

#define BATT_FULL               0
#define BATT_DISCHARGING        1
#define BATT_CHARGING           2
#define BATT_CRITICAL           5
#define BATT_NONE               7

#define BATT_FULL_MSG           "Fully charged"
#define BATT_DISCHARGING_MSG    "Discharging"
#define BATT_CHARGING_MSG       "Charging"
#define BATT_CRITICAL_MSG       "CRITICAL!"
#define BATT_NONE_MSG           "AC Line"
#define BATT_UNKNOWN_MSG        "Unknown"

#define NOTHING_FOUND_MSG       "Could not get any information from sysctl."

#define  SOCKET_PATH            "/var/run/devd.pipe"
#define  BATTERY_EVENT          "subsys=CMBAT"

typedef struct {
  int     cpu_freq;             /* current cpu frequency */
  int     cpu_freq_avail;       /* was a comaptible CPU found? */
  int     battery_life;         /* remaining battery capacity */
  int     battery_state;        /* AC state */
  int     battery_state_avail;  /* do we get a AC line state? */
  int     battery_life_avail;   /* battery information available? */
  char    freq_levels[255];     /* string containing the number of frequency levels */
  int     freq_levels_avail;    /* do we have different cpu frequencies? */
  int     battery_time;         /* how much time is left? */
  int     battery_time_avail;   /* is battery time display supported? */
  size_t  len_int;
  size_t  len_freq;
} SYSCTL_INFO;

typedef struct {
  char    *font;
  char    *color;
  int     pos_x;
  int     pos_y;
  int     width;
  double  sleeptime;            /* time to display the osd */
  int     alarm;                /* battery alarm percentage */
  int     daemon;               /* run as daemon */
} CONFIG;

static void get_sysctls(SYSCTL_INFO*);
static void show_bars(SYSCTL_INFO*, CONFIG*);
static void usage(void);
static void devd_connect(CONFIG*);

static xosd *osd = NULL;

/* vim:set ts=2 expandtab: */
